<?php
/**
 * izone functions and definitions
 *
 * @package izone
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) ) {
	$content_width = 640; /* pixels */
}

if ( ! function_exists( 'izone_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function izone_setup() {

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on izone, use a find and replace
	 * to change 'izone' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'izone', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	//add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'izone' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption',
	) );

	/*
	 * Enable support for Post Formats.
	 * See http://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array(
		'aside', 'image', 'video', 'quote', 'link',
	) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'izone_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );
}
endif; // izone_setup
add_action( 'after_setup_theme', 'izone_setup' );

/**
 * Register widget area.
 *
 * @link http://codex.wordpress.org/Function_Reference/register_sidebar
 */
function izone_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'izone' ),
		'id'            => 'sidebar-1',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );
}
add_action( 'widgets_init', 'izone_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function izone_scripts() {
	wp_enqueue_style( 'izone-style', get_stylesheet_uri() );

	wp_enqueue_script( 'browserselector', get_template_directory_uri() . '/js/browserselector.js' ); 
	wp_enqueue_script( 'jquery' );  
	wp_enqueue_script( 'navs', get_template_directory_uri() . '/js/jquery.nav.js' );   
    wp_enqueue_script( 'modernizr', get_template_directory_uri() . '/js/modernizr.js' );
    wp_enqueue_script( 'jpreloader', get_template_directory_uri() . '/js/jpreloader.js' );
    wp_enqueue_script( 'jquery.animate', get_template_directory_uri() . '/js/jquery.animate.js' );
    wp_enqueue_script( 'jquery.easing.1.3', get_template_directory_uri() . '/js/jquery.easing.1.3.js' );
    wp_enqueue_script( 'jquery.imgpreload', get_template_directory_uri() . '/js/jquery.imgpreload.js' );
    wp_enqueue_script( 'isotope.pkgd.min', get_template_directory_uri() . '/js/isotope.pkgd.min.js' );
    wp_enqueue_script( 'jquery.anchorScroll', get_template_directory_uri() . '/js/jquery.anchorScroll.js' );
    wp_enqueue_script( 'waypoints.min', get_template_directory_uri() . '/js/waypoints.min.js' );
    wp_enqueue_script( 'jquery.stellar', get_template_directory_uri() . '/js/jquery.stellar.js' );
    wp_enqueue_script( 'jquery.validate.min', get_template_directory_uri() . '/js/jquery.validate.min.js' );
    wp_enqueue_script( 'maps', get_template_directory_uri() . '/js/maps.js' );
    wp_enqueue_script( 'jquery.nivo.slider', get_template_directory_uri() . '/js/jquery.nivo.slider.js' );
    //wp_enqueue_script( 'velocity', get_template_directory_uri() . '/js/velocity.min.js' ); 
           
    wp_enqueue_script( 'custom', get_template_directory_uri() . '/js/custom.js' );   
    wp_enqueue_script( 'form', get_template_directory_uri() . '/js/form.js' );
    wp_enqueue_script( 'functions', get_template_directory_uri() . '/js/functions.js' );    

	wp_enqueue_script( 'izone-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20120206', true );

	wp_enqueue_script( 'izone-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20130115', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'izone_scripts' );

add_filter('the_content', 'my_content_manipulator');

function my_content_manipulator($content){

	//do stuff here

	return $content;

}


/**
 * Implement the Custom Header feature.
 */
//require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';


function currentUrl(){
	$url = $_SERVER['PHP_SELF'];
	$path = parse_url($url, PHP_URL_PATH);
	$segments = explode('/', rtrim($path, '/'));

	return end($segments);
}