var FormValidation = function () {

    var host = Custom.appSettings().api_url;
    
    var contact_path = '/contact/';
    var request_path = '/request/';

    var $j = jQuery;

    $j.validator.addMethod("captcha", function(value, element, params) {
      return this.optional(element) || value == parseInt(params[0]) + parseInt(params[1]);
    }, $j.validator.format("Incorrect value, please try again."));


    var handleContactValidation = function() {           
            

            var active_form = $j('#contactForm');
            var error_box = $j('.alert-danger', active_form);
            var success_box = $j('.alert-success', active_form);            

            active_form.validate({
                errorElement: 'span', //default input error message container
                errorClass: 'help-block', // default input error message class
                focusInvalid: true, // do not focus the last invalid input
                ignore: ":hidden",                
                messages: {
                    contacts_name:{
                        required: "Enter your name",
                        minlength: "Name is too short"
                    },
                    contacts_email:{
                        required: "Enter your email address",
                        email: "Enter a correct email address"
                    },                   
                    contacts_message:{                        
                        required: "Enter a message or question",
                        minlength: "Message is too short"
                    },
                    captcha: {
                        required: "Give an answer to the sum"
                    }                        
                },
                rules: {
                    contacts_name: {                        
                        required: true,
                        minlength: 3
                    },
                    contacts_email: {                        
                        required: true,
                        email: true
                    },
                    contacts_message: {
                        required: true,
                        minlength: 3
                    },
                    captcha: {
                        required: true,
                        captcha: [$j('#num1', active_form).val(), $j('#num2', active_form).val()]
                    }
                },                

                invalidHandler: function (event, validator) { //display error alert on form submit              
                    
                    success_box.hide();
                    error_box.show();                    
                    setTimeout(function() {
                        error_box.fadeOut();                                
                    }, 2000);
                },

                highlight: function (element) { // hightlight error inputs
                    $j(element)
                        .closest('.form-group').addClass('has-error'); // set error class to the control group
                },

                unhighlight: function (element) { // revert the change done by hightlight
                    $j(element)
                        .closest('.form-group').removeClass('has-error'); // set error class to the control group
                },

                success: function (label) {
                    label
                        .closest('.form-group').removeClass('has-error'); // set success class to the control group
                },

                submitHandler: function (form) {
                    

                        if($j(active_form).valid()) {                              
                                
                                error_box.hide();
                                success_box.hide();

                                var postData = JSON.stringify({
                                     "contacts_name" : $j('#contacts_name', active_form).val(), 
                                     "contacts_email" : $j('#contacts_email', active_form).val(),                                         
                                     "contacts_message" : $j('#contacts_message', active_form).val()
                                });
                                
                                $j.ajax({
                                        type: 'POST',
                                        contentType: 'application/json; charset=utf-8',
                                        url: host + contact_path,
                                        data: postData,
                                        dataType: "json",
                                        cache: false,
                                        //headers : {'Content-Type':undefined,},
                                        success: function(data, textStatus, jqXHR){

                                            var success_message = data.message;
                                            var error_message = data.error;                                            

                                            if(error_message != undefined){                                                

                                                success_box.hide(); 
                                                $j('.alert-danger .contact-message').html(error_message);
                                                error_box.fadeIn();                                                
                                                

                                            }else if(success_message != undefined){
                                                
                                                error_box.hide();
                                                $j('.alert-success .contact-message').html(success_message);
                                                success_box.fadeIn();
                                                active_form.find("input[type=text], input[type=email], textarea").val("");
                                                setTimeout(function() {
                                                    success_box.fadeOut();                                
                                                }, 3000);                                                    

                                            }else{
                                                
                                                success_box.hide();                             
                                                $j('.alert-danger .contact-message').html("Please try again").fadeIn();
                                                error_box.fadeIn();                                                    
                                            }

                                        },
                                        error: function(jqXHR, textStatus, errorThrown){
                                            
                                            success_box.hide();
                                            $j('.alert-danger .contact-message').html("Major Anticipated Error: " + jqXHR.responseText).fadeIn(); 
                                            error_box.fadeIn();                                          

                                        }

                                });//end of ajax 
                                                                 

                        }

                }//end of submitHandler

            });

    }



    var handleRequestValidation = function() {           
            

            var active_form = $j('#requestForm');
            var error_box = $j('.alert-danger', active_form);
            var success_box = $j('.alert-success', active_form);
            
            active_form.validate({
                errorElement: 'span', //default input error message container
                errorClass: 'help-block', // default input error message class
                focusInvalid: true, // do not focus the last invalid input
                ignore: ":hidden",                
                messages: {
                    request_name:{
                        required: "Enter your name",
                        minlength: "Name is too short"
                    },
                    request_email:{
                        required: "Enter your email address",
                        email: "Enter a correct email address"
                    },
                    request_phone:{
                        required: "Enter your phone number",
                        minlength: "Phone number is too short"
                    },                   
                    request_message:{                        
                        required: "Enter a message or question",
                        minlength: "Message is too short"
                    },
                    fcaptcha: {
                        required: "Give an answer to the sum"
                    }                        
                },
                rules: {
                    request_name: {                        
                        required: true,
                        minlength: 3
                    },
                    request_email: {                        
                        required: true,
                        email: true
                    },
                    request_phone:{
                        required: true,
                        minlength: 5
                    },
                    request_message: {
                        required: true,
                        minlength: 3
                    },
                    fcaptcha: {
                        required: true,
                        //requestcaptcha: true
                        captcha: [$j('#fnum', active_form).val(), $j('#snum', active_form).val()]
                    }
                },                

                invalidHandler: function (event, validator) { //display error alert on form submit              
                    
                    success_box.hide();
                    error_box.show();                    
                    setTimeout(function() {
                        error_box.fadeOut();                                
                    }, 2000);
                },

                highlight: function (element) { // hightlight error inputs
                    $j(element)
                        .closest('.form-group').addClass('has-error'); // set error class to the control group
                },

                unhighlight: function (element) { // revert the change done by hightlight
                    $j(element)
                        .closest('.form-group').removeClass('has-error'); // set error class to the control group
                },

                success: function (label) {
                    label
                        .closest('.form-group').removeClass('has-error'); // set success class to the control group
                },

                submitHandler: function (form) {
                    

                        if($j(active_form).valid()) {                              
                                
                                error_box.hide();
                                success_box.hide();

                                var postData = JSON.stringify({
                                     "request_name" : $j('#request_name', active_form).val(), 
                                     "request_email" : $j('#request_email', active_form).val(),                                         
                                     "request_phone" : $j('#request_phone', active_form).val(),                                         
                                     "request_service" : $j('#request_service', active_form).val(),                                         
                                     "request_company" : $j('#request_company', active_form).val(),                                         
                                     "request_message" : $j('#request_message', active_form).val()
                                });
                                
                                $j.ajax({
                                        type: 'POST',
                                        contentType: 'application/json; charset=utf-8',
                                        url: host + request_path,
                                        data: postData,
                                        dataType: "json",
                                        cache: false,
                                        //headers : {'Content-Type':undefined,},
                                        success: function(data, textStatus, jqXHR){

                                            var success_message = data.message;
                                            var error_message = data.error;                                            

                                            if(error_message != undefined){                                                

                                                success_box.hide(); 
                                                $j('.alert-danger .request-message').html(error_message);
                                                error_box.fadeIn();                                                
                                                

                                            }else if(success_message != undefined){
                                                
                                                error_box.hide();
                                                $j('.alert-success .request-message').html(success_message);
                                                success_box.fadeIn();
                                                active_form.find("input[type=text], input[type=email], textarea").val("");
                                                setTimeout(function() {
                                                    success_box.fadeOut();                                
                                                }, 3000);                                                    

                                            }else{
                                                
                                                success_box.hide();                             
                                                $j('.alert-danger .request-message').html("Please try again").fadeIn();
                                                error_box.fadeIn();                                                    
                                            }

                                        },
                                        error: function(jqXHR, textStatus, errorThrown){
                                            
                                            success_box.hide();
                                            $j('.alert-danger .request-message').html("Major Anticipated Error: " + jqXHR.responseText).fadeIn(); 
                                            error_box.fadeIn();                                          

                                        }

                                });//end of ajax 
                                                                 

                        }

                }//end of submitHandler

            });

    }
  

    
    return {
        //main function to initiate the module
        init: function () {
            
            handleContactValidation();
            handleRequestValidation();             
        }

    };

}();